@@ -13,6 +13,7 @@ from netbox_storage.views import (
     DriveBulkImportView,
     DriveBulkEditView,
     DriveBulkDeleteView,
+    DrivePartitionListView,
     # Filesystem Views
     FilesystemListView,
     FilesystemView,
@@ -21,7 +22,31 @@ from netbox_storage.views import (
     FilesystemBulkImportView,
     FilesystemBulkEditView,
     FilesystemBulkDeleteView,
-    # Partition
+    # Linux Device View
+    LinuxDeviceListView,
+    LinuxDeviceEditView,
+    LinuxDeviceBulkImportView,
+    LinuxDeviceBulkEditView,
+    LinuxDeviceBulkDeleteView,
+    LinuxDeviceView,
+    LinuxDeviceDeleteView,
+    # LogicalVolume Views
+    LogicalVolumeDeleteView,
+    LogicalVolumeEditView,
+    LogicalVolumeView,
+    LogicalVolumeListView,
+    LogicalVolumeBulkImportView,
+    LogicalVolumeBulkEditView,
+    LogicalVolumeBulkDeleteView,
+    # MountedVolume Views
+    MountedVolumeListView,
+    MountedVolumeEditView,
+    MountedVolumeBulkImportView,
+    MountedVolumeBulkEditView,
+    MountedVolumeBulkDeleteView,
+    MountedVolumeView,
+    MountedVolumeDeleteView,
+    # Partition Views
     PartitionListView,
     PartitionEditView,
     PartitionBulkImportView,
@@ -29,28 +54,30 @@ from netbox_storage.views import (
     PartitionBulkDeleteView,
     PartitionView,
     PartitionDeleteView,
-    # PhysicalVolume
-    DrivePartitionListView,
-    # VolumeGroup
-    # LogicalVolume
-    MountedVolumeListView,
-    MountedVolumeEditView,
-    MountedVolumeBulkImportView,
-    MountedVolumeBulkEditView,
-    MountedVolumeBulkDeleteView,
-    MountedVolumeView,
-    MountedVolumeDeleteView, LVMAddSimpleView, AddSimpleLinuxVolumeView,
+    # PhysicalVolume Views
+    PhysicalVolumeDeleteView,
+    PhysicalVolumeEditView,
+    PhysicalVolumeView,
+    PhysicalVolumeListView,
+    PhysicalVolumeBulkImportView,
+    PhysicalVolumeBulkEditView,
+    PhysicalVolumeBulkDeleteView,
+    # Simple Views
+    LVMAddSimpleView,
+    AddSimpleLinuxVolumeView,
+    # Template Views
+    TemplateLVMAddView,
+    TemplatePartitionAddView,
+    sys_topography_file,
+    # VolumeGroup Views
+    VolumeGroupDeleteView,
+    VolumeGroupEditView,
+    VolumeGroupView,
+    VolumeGroupListView,
+    VolumeGroupBulkImportView,
+    VolumeGroupBulkEditView,
+    VolumeGroupBulkDeleteView,
 )
-from netbox_storage.views.linux_device import LinuxDeviceListView, LinuxDeviceEditView, LinuxDeviceBulkImportView, \
-    LinuxDeviceBulkEditView, LinuxDeviceBulkDeleteView, LinuxDeviceView, LinuxDeviceDeleteView
-from netbox_storage.views.logical_volume import LogicalVolumeDeleteView, LogicalVolumeEditView, LogicalVolumeView, \
-    LogicalVolumeListView, LogicalVolumeBulkImportView, LogicalVolumeBulkEditView, LogicalVolumeBulkDeleteView
-from netbox_storage.views.physical_volume import PhysicalVolumeDeleteView, PhysicalVolumeEditView, PhysicalVolumeView, \
-    PhysicalVolumeListView, PhysicalVolumeBulkImportView, PhysicalVolumeBulkEditView, PhysicalVolumeBulkDeleteView
-from netbox_storage.views.template import LVMAddTemplateView, AddTemplateDriveView, \
-    AddTemplatePartitionView, SyncTemplateToVMView, sys_topography_file
-from netbox_storage.views.volume_group import VolumeGroupDeleteView, VolumeGroupEditView, VolumeGroupView, \
-    VolumeGroupListView, VolumeGroupBulkImportView, VolumeGroupBulkEditView, VolumeGroupBulkDeleteView
 
 app_name = "netbox_storage"
 
@@ -200,8 +227,7 @@ urlpatterns = [
     #
     # Template Configuration
     #
-    path('template-lvm-add/', LVMAddTemplateView.as_view(), name='template_lvm_add'),
-    path('template-drive-add/', AddTemplateDriveView.as_view(), name='template_drive_add'),
-    path('template-partition-add', AddTemplatePartitionView.as_view(), name='template_partition_add'),
+    path('template-lvm-add/', TemplateLVMAddView.as_view(), name='template_lvm_add'),
+    path('template-partition-add', TemplatePartitionAddView.as_view(), name='template_partition_add'),
     path('sync-template-to-vm/', sys_topography_file, name='sync-template-to-vm')
 ]
